import { useState } from "react";
import { Input } from "antd";
import { CompoundedComponent } from "@/types";
import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { ports } from "../data";

const component = ({ node }: { node: Node }) => {
  const { label } = node.getData();

  const [editMode, setEditMode] = useState(true);

  return (
    <>
      <div className="text-center flex items-center justify-center">
        {
          editMode ? (
            <span
              onClick={() => {
                setEditMode(false);
              }}
            >
              {label}
            </span>
          ) : (
            <Input
              variant="borderless"
              value={label}
              autoFocus
              onChange={(e) => node.setData({ label: e.target.value })}
              onBlur={() => setEditMode(false)}
            />
          )
        }
      </div>
    </>
  );
};

register({
  shape: "custom-react-text",
  width: 100,
  height: 40,
  effect: ["data"],
  component: component,
});

const Text: CompoundedComponent = {
  name: "文本",
  icon: require("./image/text.svg").default,
  node: {
    shape: "custom-react-text",
    data: {
      label: "文本节点",
    },
    ports,
  },
};

export default Text;
