import { useEffect, useRef } from "react";
import { Flex, Tabs } from "antd";
import styles from "./index.less";
import "./index.less"
import { Graph, Shape } from "@antv/x6";
import { Scroller } from '@antv/x6-plugin-scroller'
import Libary from '../Libary';
import { useModel } from "umi";
export default function Content() {
  const { initGraph } = useModel('graphModel');
  
  useEffect(() => {
    const graph = new Graph({
      container: document.getElementById("graph-container")!,
      autoResize: true,
      width: 800,
      height: 800,
      grid: {
        visible: true,
        type: "mesh",
        args: {
          color: "#ddd", // 网格线颜色
          thickness: 1, // 网格线宽度
        },
      },
      mousewheel: {
        enabled: true,
        zoomAtMousePosition: true,
        modifiers: 'ctrl',
        minScale: 0.5,
        maxScale: 3,
      },
      background: {
        color: '#eaecee',
      },
      interacting: {
        edgeLabelMovable: true,
        nodeMovable: true,
        edgeMovable: true,
      },
      connecting: {
        router: 'manhattan',
        connector: {
          name: 'rounded',
          args: {
            radius: 8,
          },
        },
        anchor: 'center',
        connectionPoint: 'anchor',
        allowBlank: true,
        snap: {
          radius: 20,
        },
        createEdge() {
          return new Shape.Edge({
            attrs: {
              line: {
                stroke: '#A2B1C3',
                strokeWidth: 2,
                targetMarker: {
                  name: 'block',
                  width: 12,
                  height: 8,
                },
              },
            },
            tools: ['segments', 'vertices'],
            zIndex: 0,
          })
        },
        validateConnection({ targetMagnet }) {
          return !!targetMagnet
        },
      },
      highlighting: {
        magnetAdsorbed: {
          name: 'stroke',
          args: {
            attrs: {
              fill: '#ff0',
              stroke: '#5F95FF',
            },
          },
        },
      },
    });

    graph.use(new Scroller({
      enabled: true
    }));
    initGraph(graph);
  }, []);

  return (
    <Flex className="h-full">
      <div className={styles.leftPanel}>
        <Tabs className="h-full" centered items={[
          {
            key: '1',
            label: '组件库',
            children: <Libary />
          },
          {
            key: '2',
            label: '风格',
            children: <div>风格面板</div>
          }
        ]}/>
      </div>
      <div className={styles.designLayout} style={{width: '100%', height: '100%'}}>
        <div id="graph-container"></div>
      </div>
    </Flex>
  );
}
