import React, { useCallback, useEffect, useRef, useState } from "react";
import { Collapse, Input, Space } from "antd";
import { basic } from "@/components/basic";
import { useModel } from "umi";
import { Dnd } from '@antv/x6-plugin-dnd';
import insertCss from 'insert-css';
export default function Libary() {
  const { graph, initDnd, startDrag } = useModel('graphModel');
  
  const containerRef = useRef<HTMLDivElement>(null);

  useEffect(() => {
    if(!containerRef.current || !graph) return;
    
    const dnd = new Dnd({
      target: graph,
      scaled: false,
      dndContainer: containerRef.current,
    });
    initDnd(dnd);
  }, [graph, containerRef.current]);

  insertCss(`
    .shalu-collapse-item {
      border-bottom: 1px solid #dfe2e5 !important;
      border-radius: 0 !important;
    }
    .shalu-tabs-content {
      height: 100%;
      overflow: auto;
    }
  `);
  
  const renderItem = (data: any, key: number) => {
      return <img className="w-32px cursor-move" key={key} src={data.icon} onMouseDown={(e) => startDrag(e, data.node)}/>;
  };

  const [items, setItems] = useState([
    {
      key: "1",
      label: "基础图形",
      children: <Space wrap size={6}>{basic.map((item, index) => renderItem(item, index))}</Space>,
    },
    {
      key: "2",
      label: "Flowchart流程图",
      children: <Space wrap size={6}>{basic.map((item, index) => renderItem(item, index))}</Space>,
    },
    {
      key: "3",
      label: "E-R图",
      children: <Space wrap size={6}>{basic.map((item, index) => renderItem(item, index))}</Space>,
    },
  ]);

  const [activeKeys, setActiveKeys] = useState(["1", "2", "3"]);

  const handleChange = (keys: string | string[]) => {
    setActiveKeys(Array.isArray(keys) ? keys : [keys]);
  };
  return (
    <div ref={containerRef} className="h-full overflow-auto">
      <div className="px-4">
        <Input size="small" allowClear placeholder="请输入搜索内容" />
      </div>
      <Collapse
        ghost
        items={items}
        activeKey={activeKeys}
        onChange={handleChange}
      />
    </div>
  );
}
